# Interactive Python session skipped by phmdoctest directive.



<!--phmdoctest-skip-->
```py
>>> int('def')    #doctest:+IGNORE_EXCEPTION_DETAIL
Traceback (most recent call last):
    ...
ValueError:
```
